//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yaku](index.md)/[isYakuman](is-yakuman.md)

# isYakuman

[common]\
val [isYakuman](is-yakuman.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = false

是否为役满役种
